@@ -27,8 +27,8 @@ def is_name_valid(app_name):
 
 #get all arguments passed
 def get_args():
-  args = sys.argv
-  args.pop(0)
+  args = sys.argv[2:]
+  print(args)
   return args
 
 def is_args_valid(args):
